# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'kong_admin_password',
    'kong_admin_token',
    'kong_admin_uri',
    'kong_admin_username',
    'kong_api_key',
    'strict_plugins_match',
    'tls_skip_verify',
]

__config__ = pulumi.Config('kong')

kong_admin_password = __config__.get('kongAdminPassword')
"""
An basic auth password for kong admin
"""

kong_admin_token = __config__.get('kongAdminToken')
"""
API key for the kong api (Enterprise Edition)
"""

kong_admin_uri = __config__.get('kongAdminUri')
"""
The address of the kong admin url e.g. http://localhost:8001
"""

kong_admin_username = __config__.get('kongAdminUsername')
"""
An basic auth user for kong admin
"""

kong_api_key = __config__.get('kongApiKey')
"""
API key for the kong api (if you have locked it down)
"""

strict_plugins_match = __config__.get('strictPluginsMatch') or _utilities.get_env_bool('STRICT_PLUGINS_MATCH')
"""
Should plugins `config_json` field strictly match plugin configuration
"""

tls_skip_verify = __config__.get('tlsSkipVerify') or (_utilities.get_env_bool('TLS_SKIP_VERIFY') or False)
"""
Whether to skip tls verify for https kong api endpoint using self signed or untrusted certs
"""

